==> property_map-0.0.15.tar.gz: test.dart <==

import 'lib/property_map.dart';
import 'dart:json';

class Test extends Serializable{

    String message;

    Test(this.message) {

    }

    String toJson() {
      return '{"_type_":"Test", "message":"${message}"}';
    }

}

void main() {
  // Create a PropertyMap
  var c = new PropertyContainerConfig();
  c.useCustomDeserializers = false;
  var data = new PropertyMap(c);

  // Just add properties.
  data.name = "Daniel";
  data.age = 25;

  // [] works too, if you prefer it.
  data['phone'] = "621-222-1155";

  // Add a List. It will be automatically converted to a PropertyList.
  data.enemies = ['Lucia', 'John', 'Alex'];

  // But exposes the same API.
  data.enemies.add('Susan');

  // Maps are converted to PropertyMaps so you can compose them.
  data.games = {'important': true, 'fun':true, 'numberOwned':9999};

  // You can simply keep adding properties to nested maps.
  data.games.favorites = ['Braid', 'Portal'];

  var k = {'a':{'b':[0,1,2]}};
  data.test = k;
  //print(data.test.a.b[1]);

  /*data.addRawElement("illegal", new Test());
  print(data.illegal);*/

  // Read values.
  /*print(data.name);
  print(data.games.favorites[0]);

  // Serialize them all.
  print(data.toJson());*/

  PropertyMap.registerCustomDeserializer('Test', (value, config) {
    return new Test(value['message']);
  });

  /*data.map = {'_type_': 'Test', 'message':'secret message!!!'};
  print(data.map.configuration.useCustomDeserializers);

  var json = parse(data.toJson());
  var m = PropertyContainer.validate(json, c);
  print(m.map);
  print(m.map.message);*/

  var m = PropertyMap.promote({'name': 'Test', 'message':'secret message!!!', 'nested':[1,2,3,4,'test',['a,''b','c']]});
  print(m);
  print(m.toJson());
}

==> property_map-0.0.16.tar.gz: test.dart <==

import 'lib/property_map.dart';
import 'dart:json';

class Test extends Serializable{
    String message;
    Test(this.message) {}
    String toJson() => '{"_type_":"Test", "message":"${message}"}';
}

void main() {
  // Create a PropertyMap
  var c = new PropertyMapConfig();
  c.useCustomDeserializers = false;
  var data = new PropertyMap(c);

  // Just add properties.
  data.name = "Daniel";
  data.age = 25;

  // [] works too, if you prefer it.
  data['phone'] = "621-222-1155";

  // Add a List. It will be automatically converted to a PropertyList.
  data.enemies = ['Lucia', 'John', 'Alex'];

  // But exposes the same API.
  data.enemies.add('Susan');

  // Maps are converted to PropertyMaps so you can compose them.
  data.games = {'important': true, 'fun':true, 'numberOwned':9999};

  // You can simply keep adding properties to nested maps.
  data.games.favorites = ['Braid', 'Portal'];

  var k = {'a':{'b':[0,1,2]}};
  data.test = k;
  //print(data.test.a.b[1]);

  /*data.addRawElement("illegal", new Test());
  print(data.illegal);*/

  // Read values.
  /*print(data.name);
  print(data.games.favorites[0]);

  // Serialize them all.
  print(data.toJson());*/

  PropertyMap.registerCustomDeserializer('Test', (value, config) {
    return new Test(value['message']);
  });

  /*data.map = {'_type_': 'Test', 'message':'secret message!!!'};
  print(data.map.configuration.useCustomDeserializers);

  var json = parse(data.toJson());
  var m = PropertyContainer.validate(json, c);
  print(m.map);
  print(m.map.message);*/

  var m = PropertyMap.promote({'name': 'Test', 'message':'secret message!!!', 'nested':[1,2,3,4,'test',['a,''b','c']]});
  print(m);
  print(m.toJson());
}
